# API Reference

This page provides the API reference for TrackNado.

## Hub Building
::: tracknado.builder.HubBuilder
::: tracknado.api.HubGenerator
::: tracknado.api.TrackDesign

## Data Models
::: tracknado.models.Track
::: tracknado.models.TrackGroup

## File Converters
::: tracknado.converters.convert_bed_to_bigbed
::: tracknado.converters.convert_gtf_to_biggenepred

## Metadata Extractors
::: tracknado.extractors.from_seqnado_path
::: tracknado.extractors.from_filename_pattern
::: tracknado.extractors.from_parent_dirs

## Validation
::: tracknado.validation.validate_hub
::: tracknado.validation.HubValidator
